==> renku-0.10.1.dev6.tar.gz: renku-0.10.1.dev6/renku/core/commands/checks/external.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2020 - Swiss Data Science Center (SDSC)
# A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
# Eidgenössische Technische Hochschule Zürich (ETHZ).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Checks for external files."""
from pathlib import Path

import click

from renku.core.commands.echo import WARNING


def check_missing_external_files(client):
    """Find external files that are missing."""
    missing = []

    for path, dataset in client.datasets.items():
        for file_ in dataset.files:
            if file_.external:
                target = Path(file_.path).resolve()
                if not target.exists():
                    missing.append((file_.path, str(target)))

    if not missing:
        return True, None

    problems = (
        '\n' + WARNING + 'There are missing external files.\n'
        '  (make sure that external paths are accessible)' + '\n\n\t' +
        '\n\t'.join(
            click.style(path, fg='yellow') + ' -> ' +
            click.style(target, fg='red') for path, target in missing
        ) + '\n'
    )
    return False, problems

==> renku-0.10.5.dev82.tar.gz: renku-0.10.5.dev82/renku/core/commands/checks/external.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2020 - Swiss Data Science Center (SDSC)
# A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
# Eidgenössische Technische Hochschule Zürich (ETHZ).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Checks for external files."""
import click

from renku.core.commands.echo import WARNING


def check_missing_external_files(client):
    """Find external files that are missing."""
    missing = []

    for path, dataset in client.datasets.items():
        for file_ in dataset.files:
            if file_.external:
                target = (client.path / file_.path).resolve()
                if not target.exists():
                    missing.append((file_.path, str(target)))

    if not missing:
        return True, None

    problems = (
        "\n" + WARNING + "There are missing external files.\n"
        "  (make sure that external paths are accessible)"
        + "\n\n\t"
        + "\n\t".join(
            click.style(path, fg="yellow") + " -> " + click.style(target, fg="red") for path, target in missing
        )
        + "\n"
    )
    return False, problems
